// SPDX-License-Identifier: BSD-3-Clause
// ignore_for_file: constant_identifier_names

part of 'git_repository.dart';

class GitErrorCode {
  /// No error
  static const int GIT_OK = 0;

  /// Generic error
  static const int GIT_ERROR = -1;

  /// Requested object could not be found
  static const int GIT_ENOTFOUND = -3;

  /// Object exists preventing operation
  static const int GIT_EEXISTS = -4;

  /// More than one object matches
  static const int GIT_EAMBIGUOUS = -5;

  /// Output buffer too short to hold data
  static const int GIT_EBUFS = -6;

  /* GIT_EUSER is a special error that is never generated by libgit2
	 * code.  You can return it from a callback (e.g to stop an iteration)
	 * to know that it was generated by the callback and not by libgit2. */
  /// Callback generated error
  static const int GIT_EUSER = -7;

  /// Operation not allowed on bare repository
  static const int GIT_EBAREREPO = -8;

  /// HEAD refers to branch with no commits
  static const int GIT_EUNBORNBRANCH = -9;

  /// Merge in progress prevented operation
  static const int GIT_EUNMERGED = -10;

  /// Reference was not fast-forwardable
  static const int GIT_ENONFASTFORWARD = -11;

  /// Name/ref spec was not in a valid format
  static const int GIT_EINVALIDSPEC = -12;

  /// Checkout conflicts prevented operation
  static const int GIT_ECONFLICT = -13;

  /// Lock file prevented operation
  static const int GIT_ELOCKED = -14;

  /// Reference value does not match expected
  static const int GIT_EMODIFIED = -15;

  /// Authentication error
  static const int GIT_EAUTH = -16;

  /// Server certificate is invalid
  static const int GIT_ECERTIFICATE = -17;

  /// Patch/merge has already been applied
  static const int GIT_EAPPLIED = -18;

  /// The requested peel operation is not possible
  static const int GIT_EPEEL = -19;

  /// Unexpected EOF
  static const int GIT_EEOF = -20;

  /// Invalid operation or input
  static const int GIT_EINVALID = -21;

  /// Uncommitted changes in index prevented operation
  static const int GIT_EUNCOMMITTED = -22;

  /// The operation is not valid for a directory
  static const int GIT_EDIRECTORY = -23;

  /// A merge conflict exists and cannot continue
  static const int GIT_EMERGECONFLICT = -24;

  /// Internal only
  static const int GIT_PASSTHROUGH = -30;

  /// Signals end of iteration with iterator
  static const int GIT_ITEROVER = -31;

  /// Internal only
  static const int GIT_RETRY = -32;

  /// Hashsum mismatch in object
  static const int GIT_EMISMATCH = -33;
}

class GitError {
  static const int GITERR_NONE = 0;
  static const int GITERR_NOMEMORY = 1;
  static const int GITERR_OS = 2;
  static const int GITERR_INVALID = 3;
  static const int GITERR_REFERENCE = 4;
  static const int GITERR_ZLIB = 5;
  static const int GITERR_REPOSITORY = 6;
  static const int GITERR_CONFIG = 7;
  static const int GITERR_REGEX = 8;
  static const int GITERR_ODB = 9;
  static const int GITERR_INDEX = 10;
  static const int GITERR_OBJECT = 11;
  static const int GITERR_NET = 12;
  static const int GITERR_TAG = 13;
  static const int GITERR_TREE = 14;
  static const int GITERR_INDEXER = 15;
  static const int GITERR_SSL = 16;
  static const int GITERR_SUBMODULE = 17;
  static const int GITERR_THREAD = 18;
  static const int GITERR_STASH = 19;
  static const int GITERR_CHECKOUT = 20;
  static const int GITERR_FETCHHEAD = 21;
  static const int GITERR_MERGE = 22;
  static const int GITERR_SSH = 23;
  static const int GITERR_FILTER = 24;
  static const int GITERR_REVERT = 25;
  static const int GITERR_CALLBACK = 26;
  static const int GITERR_CHERRYPICK = 27;
  static const int GITERR_DESCRIBE = 28;
  static const int GITERR_REBASE = 29;
  static const int GITERR_FILESYSTEM = 30;
  static const int GITERR_PATCH = 31;
  static const int GITERR_WORKTREE = 32;
  static const int GITERR_SHA1 = 33;
}

class GitBranchT {
  static const int GIT_BRANCH_LOCAL = 1;
  static const int GIT_BRANCH_REMOTE = 2;
  static const int GIT_BRANCH_ALL = GIT_BRANCH_LOCAL | GIT_BRANCH_REMOTE;
}
